pub enum Resolved {
One(IpAddr),
Many(Vec<IpAddr>),
NodeIds(Vec<NodeId>),
}Expand description
The result of a successful resolution of a Resolver.
Variants
One(IpAddr)
The given name has been resolved to a single IpAddr.
Many(Vec<IpAddr>)
The given name has been resolved to multiple IpAddrs.
NodeIds(Vec<NodeId>)
The given name has been resolved to a new list of NodeIds
obtained from DNS TXT records representing possible alternatives.