Resolver

Struct Resolver 

pub struct Resolver { /* private fields */ }

Implementations

Source

impl Resolver

pub fn new() -> Result<Self>

Creates a new Resolver with the default resolver configuration (Cloudflare) and options.

pub fn custom(cfg: ResolverConfig, opts: ResolverOpts) -> Self

Creates a Resolver with a custom resolver configuration and options.

pub fn system() -> Result<Self>

Creates a new Resolver from the OS’s DNS configuration and defaults.

pub fn from_option(option: ResolverOption) -> Result<Self>

pub async fn lookup_ip(&self, name: String) -> Result<Vec<IpAddr>, ResolveError>

pub async fn ipv4_lookup( &self, name: String, ) -> Result<Vec<Ipv4Addr>, ResolveError>

pub async fn ipv6_lookup( &self, name: String, ) -> Result<Vec<Ipv6Addr>, ResolveError>

pub async fn txt_lookup(&self, name: String) -> Result<TxtLookup, ResolveError>

pub async fn resolve(&self, name: String) -> Result<Resolved, ResolveError>

pub async fn resolve_addr(&self, addr: &mut StackAddr) -> Result<()>